@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 
 use base qw/Class::Accessor::Fast/;
 
@@ -15,8 +15,8 @@ use Shipwright::Util;
 use Shipwright::Backend;
 use Shipwright::Source;
 use Shipwright::Build;
-use File::Temp qw/tempdir/;
-use File::Spec::Functions qw/catfile/;
+use File::Temp qw/tempfile/;
+use File::Spec::Functions qw/catfile tmpdir/;
 
 sub new {
     my $class = shift;
@@ -28,9 +28,7 @@ sub new {
 
         # a better named log_file, in the name of repository
         my $info = join '', map { /\w/ ? $_ : '_' } split //, $args{repository};
-        $args{log_file} =
-          catfile( tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 ),
-            "shipwright_${info}.log" );
+        $args{log_file} = catfile( tmpdir(), "shipwright_$info.log" );
     }
 
     my $self = {
