@@ -7,11 +7,12 @@ use Carp;
 use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
 __PACKAGE__->mk_accessors(
     qw/build_base skip skip_test only_test install_base
-      force log_file flags name perl only with/
+      force log_file flags name perl only with make/
 );
 
 use Shipwright;
 use Cwd 'abs_path';
+use File::Spec::Functions qw/catdir/;
 
 sub options {
     (
@@ -26,6 +27,7 @@ sub options {
         'force'          => 'force',
         'perl'           => 'perl',
         'with=s'         => 'with',
+        'make=s'         => 'make',
     );
 }
 
@@ -38,7 +40,7 @@ sub run {
     if ( $self->install_base ) {
 
         # convert relative path to be absolute
-        $self->install_base( rel2abs( $self->install_base ) );
+        $self->install_base( abs_path( $self->install_base ) );
     }
 
     unless ( $self->name ) {
@@ -71,8 +73,7 @@ sub run {
             name   => $name,
             source => $self->with->{$name},
             follow => 0,
-            map { $_ => $self->$_ }
-              qw/repository only_test perl/
+            map { $_ => $self->$_ } qw/repository only_test perl/
         );
         $source{$name} = $shipwright->source->run;
     }
@@ -80,14 +81,14 @@ sub run {
     my $shipwright = Shipwright->new(
         map { $_ => $self->$_ }
           qw/repository log_level log_file skip skip_test
-          flags name force only_test install_base build_base perl only/
+          flags name force only_test install_base build_base perl only make/
     );
 
     $shipwright->backend->export( target => $shipwright->build->build_base );
 
     my $dists_dir = $shipwright->build->build_base;
     for my $name ( keys %source ) {
-        my $dir = catfile( $dists_dir, 'dists', $name );
+        my $dir = catdir( $dists_dir, 'dists', $name );
         system("rm -rf $dir");
         system("cp -r $source{$name} $dir");
     }
@@ -123,6 +124,7 @@ Shipwright::Script::Build - Build the specified project
  --name NAME                  : specify the name of the project
  --perl PATH                  : specify the path of perl that run the commands
                                 in scripts/
+ --make PATH                  : specify the path of make command
  --with name=source,...       : don't build the dist of the name in repo,
                                 use the one specified here instead.
 
