@@ -23,7 +23,7 @@ sub run {
     my $self = shift;
     my $name = shift;
 
-    die "need name arg\n" unless $name;
+    confess "need name arg\n" unless $name;
 
     if ( $name =~ /^__/ ) {
         print "$name can't start as __\n";
@@ -38,12 +38,12 @@ sub run {
     {
 
         # show without change
-        $self->_show_flags($flags, $name);
+        $self->_show_flags( $flags, $name );
         return;
     }
 
     unless ( 1 == grep { defined $_ } $self->add, $self->delete, $self->set ) {
-        die "you should specify one and only one of add, delete and set\n";
+        confess "you should specify one and only one of add, delete and set\n";
     }
 
     my $list;
