@@ -8,7 +8,7 @@ use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
 __PACKAGE__->mk_accessors(qw/all follow builder utility version/);
 
 use Shipwright;
-use File::Spec::Functions qw/catfile catdir/;
+use File::Spec::Functions qw/catdir/;
 use Shipwright::Util;
 use File::Copy qw/copy move/;
 use File::Temp qw/tempdir/;
@@ -124,6 +124,11 @@ sub _update {
             confess 'invalid name ' . $name . "\n";
         }
 
+        unless ( $s ) {
+            warn "can't find the source of $name, skipping";
+            next;
+        }
+
         $shipwright->source(
             Shipwright::Source->new(
                 source  => "cpan:$s",
@@ -138,7 +143,7 @@ sub _update {
     $version = Shipwright::Util::LoadFile( $shipwright->source->version_path );
 
     $shipwright->backend->import(
-        source    => catfile( $shipwright->source->directory, $name ),
+        source    => catdir( $shipwright->source->directory, $name ),
         comment   => "update $name",
         overwrite => 1,
         version   => $version->{$name},
