@@ -13,8 +13,9 @@ use Cwd qw/getcwd/;
 use base qw/Class::Accessor::Fast/;
 __PACKAGE__->mk_accessors(
     qw/source directory scripts_directory download_directory follow
-      min_perl_version map_path skip map keep_recommends keep_build_requires
-      name log url_path version_path version/
+      min_perl_version map_path skip skip_recommends skip_all_recommends
+      map keep_recommends keep_build_requires name log url_path version_path 
+      version/
 );
 
 =head1 NAME
@@ -66,6 +67,7 @@ sub _follow {
     my $map          = {};
     my $url          = {};
 
+
     unless ( $self->min_perl_version ) {
         no warnings 'once';
         require Config;
@@ -82,11 +84,19 @@ sub _follow {
         $url = Shipwright::Util::LoadFile( $self->url_path );
     }
 
+    my @types = qw/requires build_requires/;
+
+    my $reverse_map = { reverse %$map };
+    my $skip_recommends = $self->skip_recommends->{ $self->name }
+      || $self->skip_recommends->{ $reverse_map->{ $self->name } }
+      || $self->skip_all_recommends;
+    push @types, 'recommends' unless $skip_recommends;
+
     if ( !-e $require_path ) {
 
         # if not found, we'll create one according to Build.PL or Makefile.PL
         my $require = {};
-        chdir catfile($path);
+        chdir catdir($path);
 
         if ( -e 'Build.PL' ) {
             Shipwright::Util->run( [ $^X, 'Build.PL' ] );
@@ -159,9 +169,9 @@ sub shipwright_features {
 #     ],
 # );
                for ( my $j = 0; $j < @{$mods->[$i]}; $j++ ) {
-                    if ( $mods->[$i][$j+1] =~ /^[\d\.]+$/ ) {
+                    if ( $mods->[$i][$j+1] =~ /^[\d\.]*$/ ) {
                         $shipwright_req->{recommends}{$mods->[$i][$j]} 
-                            = $mods->[$i][$j+1];
+                            = $mods->[$i][$j+1] || 0;
                         $j++;
                     }
                     else {
@@ -172,9 +182,9 @@ sub shipwright_features {
                 next;
             }
 
-            if ( $mods->[$i+1] =~ /^[\d\.]+$/ ) {
+            if ( $mods->[$i+1] =~ /^[\d\.]*$/ ) {
                 # index $i+1 is a version
-                $shipwright_req->{recommends}{$mods->[$i]} = $mods->[$i+1];
+                $shipwright_req->{recommends}{$mods->[$i]} = $mods->[$i+1] || 0;
                 $i++;
             }
             else {
@@ -235,7 +245,7 @@ EOF
             Shipwright::Util->run( [ 'rm',   'Makefile.old' ] );
         }
 
-        for my $type (qw/requires recommends build_requires/) {
+        for my $type ( @types ) {
             for my $module ( keys %{ $require->{$type} } ) {
                 $require->{$type}{$module}{version} =
                   delete $require->{$type}{$module};
@@ -257,9 +267,12 @@ EOF
             }
         }
 
-        for my $type (qw/requires recommends build_requires/) {
+        for my $type ( @types ) {
             for my $module ( keys %{ $require->{$type} } ) {
 
+#the name shouldn't be undefined, but it _indeed_ happens in reality sometimes
+                next unless $module;
+
                 # we don't want to require perl
                 if ( $module eq 'perl' ) {
                     delete $require->{$type}{$module};
@@ -359,6 +372,9 @@ EOF
                 }
             }
         }
+        # don't keep recommends info if we skip them, so we won't encounter
+        # them when update later
+        $require->{recommends} = {} if $skip_recommends;
 
         Shipwright::Util::DumpFile( $require_path, $require );
     }
