@@ -5,10 +5,11 @@ use strict;
 use Carp;
 
 use Shipwright::Source::Compressed;
+use File::Spec::Functions qw/catfile/;
 
 use base qw/Shipwright::Source::Base/;
 
-$ENV{'FTP_PASSIVE'} = 1; # force enable passive mode, seems safe nowadays
+$ENV{'FTP_PASSIVE'} = 1;    # force enable passive mode, seems safe nowadays
 
 =head2 run
 
@@ -47,7 +48,7 @@ sub _run {
 
         if ( $response->is_success ) {
             open my $fh, '>', $self->source
-              or die "can't open file " . $self->source . ": $!";
+              or confess "can't open file " . $self->source . ": $!";
             print $fh $response->content;
         }
         else {
